@@ -228,18 +228,30 @@ class DBMonitorProvider(object):
         tipo = EnvironmentAttr.objects.get(
             dbaas_environment=environment).dbmonitor_environment
 
+        if databaseinfra.ssl_configured:
+            ssl_habilitado = 'true'
+        else:
+            ssl_habilitado = 'false'
+
+        if databaseinfra.ssl_mode == databaseinfra.REQUIRETLS:
+            ssl_obrigatorio = 'true'
+        else:
+            ssl_obrigatorio = 'false'
+
         sql = """INSERT INTO dbmonitor_database ( nome, maquina, sgbd, topologia, tipo, dns, porta, versao, usuario, senha,
                              ativo, flag_cluster, coleta_info_sessoes, coleta_info_tablespaces, coleta_info_segmentos,
                              coleta_info_backup, coleta_info_key_buffer, testa_conexao, coleta_tamanho_database,
                              flag_autenticacao, testa_replicacao, testa_lock, replicaset,
-                             disk_path, tipo_maquina, dbaas, organizacao_id, cloud_id)
+                             disk_path, tipo_maquina, dbaas, organizacao_id, cloud_id,
+                             testa_query_lenta, ssl_habilitado, ssl_obrigatorio)
                  VALUES (
                  '%(nome)s', '%(maquina)s', '%(sgbd)s', %(topologia)s, '%(tipo)s', '%(dns)s', '%(porta)s', '%(versao)s', '%(usuario)s',
                  encode('%(senha)s', '%(decodekey)s'),
                  %(ativo)s, %(flag_cluster)s, %(coleta_info_sessoes)s, %(coleta_info_tablespaces)s, %(coleta_info_segmentos)s,
                  %(coleta_info_backup)s, %(coleta_info_key_buffer)s, %(testa_conexao)s, %(testa_lock)s, %(coleta_tamanho_database)s,
                  %(flag_autenticacao)s, %(testa_replicacao)s, '%(replicaset)s',
-                 '%(disk_path)s', '%(tipo_maquina)s', %(dbaas)s, %(organizacao_id)s, %(cloud_id)s
+                 '%(disk_path)s', '%(tipo_maquina)s', %(dbaas)s, %(organizacao_id)s, %(cloud_id)s,
+                 %(testa_query_lenta)s, %(ssl_habilitado)s, %(ssl_obrigatorio)s
                  )
         """ % {
             'nome': databaseinfra.name[:50],
@@ -249,7 +261,7 @@ class DBMonitorProvider(object):
             'tipo': tipo,
             'dns': dns,
             'porta': port,
-            'versao': databaseinfra.engine.version,
+            'versao': databaseinfra.engine_patch.full_version,
             'usuario': databaseinfra.user,
             'senha': databaseinfra.password,
             'decodekey': self.DECODE_KEY,
@@ -271,6 +283,9 @@ class DBMonitorProvider(object):
             'dbaas': 'true',
             'organizacao_id': organizacao_id,
             'cloud_id': cloud_id,
+            'testa_query_lenta': 'false',
+            'ssl_habilitado': ssl_habilitado,
+            'ssl_obrigatorio': ssl_obrigatorio,
         }
 
         try:
@@ -452,7 +467,7 @@ class DBMonitorProvider(object):
     @transaction.commit_on_success
     def update_dbmonitor_database_version(self, databaseinfra, new_version):
         databaseinfra_attr = DatabaseInfraAttr.objects.get(dbaas_databaseinfra=databaseinfra)
-
+        LOG.info('update_dbmonitor_database_version {}{}'.format(databaseinfra, new_version))
         LOG.info('Updating DBMonitor database version')
         sql = """UPDATE dbmonitor_database
                  set versao = '%(versao)s'
@@ -643,3 +658,37 @@ class DBMonitorProvider(object):
         except Exception, e:
             LOG.error(str(e))
             raise e
+
+    @classmethod
+    @transaction.commit_on_success
+    def update_database_ssl_info(cls, databaseinfra):
+        LOG.info('Updating database SSL info')
+        try:
+            cls.auth(databaseinfra.environment)
+
+            databaseinfra_attr = DatabaseInfraAttr.objects.get(dbaas_databaseinfra=databaseinfra)
+            if databaseinfra.ssl_configured:
+                ssl_habilitado = 'true'
+            else:
+                ssl_habilitado = 'false'
+
+            if databaseinfra.ssl_mode == databaseinfra.REQUIRETLS:
+                ssl_obrigatorio = 'true'
+            else:
+                ssl_obrigatorio = 'false'
+
+            sql = """UPDATE dbmonitor_database
+                     set ssl_habilitado = {}, ssl_obrigatorio = {}
+                     WHERE id = {}
+            """.format(ssl_habilitado,
+                ssl_obrigatorio,
+                databaseinfra_attr.dbmonitor_databaseinfra)
+
+            cursor = cls.client.cursor()
+            cursor.execute(sql)
+
+            cls.client.commit()
+            LOG.info('DBMonitor database SSL info successfully updated!')
+        except Exception, e:
+            LOG.error(str(e))
+            raise e
\ No newline at end of file
